@@ -1,6 +1,6 @@
 package App::PerlWatcher::Engine;
 {
-  $App::PerlWatcher::Engine::VERSION = '0.14';
+  $App::PerlWatcher::Engine::VERSION = '0.15';
 }
 # ABSTRACT: Creates Watchers and lets them  notify Frontend with their's Statuses
 
@@ -22,6 +22,8 @@ use App::PerlWatcher::Util::Bootstrap qw/get_home_dir/;
 use App::PerlWatcher::Util::Storable qw/freeze thaw/;
 
 
+
+
 has 'frontend'          => ( is => 'rw');
 
 
@@ -134,7 +136,7 @@ App::PerlWatcher::Engine - Creates Watchers and lets them  notify Frontend with
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -192,6 +194,11 @@ version 0.14
  # warn
  # ...
 
+=head1 DESCRIPTION
+
+The more detailed description of PerlWatcher application can be found here:
+L<https://github.com/basiliscos/perl-watcher>
+
 =head1 ATTRIBUTES
 
 =head2 config
