@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::Weather;
 {
-  $App::PerlWatcher::Watcher::Weather::VERSION = '0.14';
+  $App::PerlWatcher::Watcher::Weather::VERSION = '0.15';
 }
 # ABSTRACT: Weather watches based around api.yr.no. Currenlty monitors only temperature and does no any notifications / level alerts.
 
@@ -48,7 +48,7 @@ sub _build_url {
 
 sub description {
     my $self = shift;
-    my $desc = "Weather ";
+    my $desc = "";
     my %data = %{ $self->data // {} };
     if ( %data ) {
         $desc .= join(q{, } ,
@@ -90,7 +90,7 @@ App::PerlWatcher::Watcher::Weather - Weather watches based around api.yr.no. Cur
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 ATTRIBUTES
 
